Histograms
==========

histbook has only one histogram class, which can have arbitrarily many independent dimensions (binned axes) and dependent dimensions (profiles). Plotable one and two-dimensional histograms are derived by projection.

.. autoclass:: histbook.hist.Hist
   :members: 
   :inherited-members: 
